@@ -4,7 +4,7 @@
 #' @keywords datasets
 #' @family datasets
 #' @source
-#' Constructed using `ex` from the `{admiral` package
+#' Constructed using `ex` from the `{admiral}` package
 #'
 "admiralophtha_ex"
 
@@ -14,7 +14,7 @@
 #' @keywords datasets
 #' @family datasets
 #' @source
-#' Derived from the `oe` and `ADSL` datasets using `{admiral`, `{admiralophtha}` and
+#' Derived from the `oe` and `ADSL` datasets using `{admiral}`, `{admiralophtha}` and
 #' (\url{https://github.com/pharmaverse/admiralophtha/blob/main/inst/templates/ad_adbcva.R})
 #'
 "admiralophtha_adbcva"
@@ -25,7 +25,7 @@
 #' @keywords datasets
 #' @family datasets
 #' @source
-#' Derived from the `ADSL` and `qs` datasets using `{admiral`, `{admiralophtha}` and
+#' Derived from the `ADSL` and `qs` datasets using `{admiral}`, `{admiralophtha}` and
 #' (\url{https://github.com/pharmaverse/admiralophtha/blob/main/inst/templates/ad_advfq.R})
 #'
 "admiralophtha_advfq"
@@ -36,7 +36,17 @@
 #' @keywords datasets
 #' @family datasets
 #' @source
-#' Derived from the `oe` and `ADSL` datasets using `{admiral`, `{admiralophtha}` and
+#' Derived from the `oe` and `ADSL` datasets using `{admiral}`, `{admiralophtha}` and
 #' (\url{https://github.com/pharmaverse/admiralophtha/blob/main/inst/templates/ad_adoe.R})
 #'
 "admiralophtha_adoe"
+
+#' Ophthalmology Questionnaires SDTM Dataset
+#'
+#' An example Questionnaires SDTM dataset with ophthalmology-specific questionnaire of NEI VFQ-25
+#' @keywords datasets
+#' @family datasets
+#' @source
+#' Constructed using `qs` from the `{admiral}` package
+#'
+"admiralophtha_qs"
